@@ -36,9 +36,13 @@ class Server(object):
 
 		kwargs = {}
 
-		if self._username and self._password:
+		if self._username:
+			kwargs.update({
+				'username': self._username
+			})
+		
+		if self._password:
 			kwargs.update({
-				'username': self._username,
 				'password': self._password
 			})
 
